==> sdlmame_0.123.orig.tar.gz: sdlmame-0.123/src/osd/sdl/debug-cb.h <==
#include <gtk/gtk.h>


void
on_new_mem_activate                    (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_new_disasm_activate                 (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_run_activate                        (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_run_h_activate                      (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_run_cpu_activate                    (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_run_irq_activate                    (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_run_vbl_activate                    (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_step_into_activate                  (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_step_over_activate                  (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_step_out_activate                   (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

GtkWidget*
debug_view_new (gchar *widget_name, gchar *string1, gchar *string2,
                gint int1, gint int2);

GtkWidget*
dview_new (gchar *widget_name, gchar *string1, gchar *string2,
                gint int1, gint int2);

GtkWidget*
dview_new (gchar *widget_name, gchar *string1, gchar *string2,
                gint int1, gint int2);

GtkWidget*
dview_new (gchar *widget_name, gchar *string1, gchar *string2,
                gint int1, gint int2);

GtkWidget*
dview_new (gchar *widget_name, gchar *string1, gchar *string2,
                gint int1, gint int2);

GtkWidget*
dview_new (gchar *widget_name, gchar *string1, gchar *string2,
                gint int1, gint int2);

GtkWidget*
dview_new (gchar *widget_name, gchar *string1, gchar *string2,
                gint int1, gint int2);

void
on_raw_opcodes_activate                (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_enc_opcodes_activate                (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_comments_activate                   (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_new_errorlog_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_soft_reset_activate                 (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_hard_reset_activate                 (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_exit_activate                       (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_chunks_1_activate                   (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_chunks_2_activate                   (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_chunks_4_activate                   (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_reverse_activate                    (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_ibpl_activate                       (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_dbpl_activate                       (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

GtkWidget*
dview_new (gchar *widget_name, gchar *string1, gchar *string2,
                gint int1, gint int2);

void
on_raw_opcodes_activate                (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_enc_opcodes_activate                (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_comments_activate                   (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

==> sdlmame_0.129.orig.tar.gz: sdlmame-0.129/src/osd/sdl/debug-cb.h <==
#include <gtk/gtk.h>


void
on_new_mem_activate                    (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_new_disasm_activate                 (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_run_activate                        (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_run_h_activate                      (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_run_cpu_activate                    (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_run_irq_activate                    (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_run_vbl_activate                    (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_step_into_activate                  (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_step_over_activate                  (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_step_out_activate                   (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

GtkWidget*
debug_view_new (gchar *widget_name, gchar *string1, gchar *string2,
                gint int1, gint int2);

GtkWidget*
dview_new (const gchar *widget_name, const gchar *string1, const gchar *string2,
                gint int1, gint int2);

GtkWidget*
dview_new (const gchar *widget_name, const gchar *string1, const gchar *string2,
                gint int1, gint int2);

GtkWidget*
dview_new (const gchar *widget_name, const gchar *string1, const gchar *string2,
                gint int1, gint int2);

GtkWidget*
dview_new (const gchar *widget_name, const gchar *string1, const gchar *string2,
                gint int1, gint int2);

GtkWidget*
dview_new (const gchar *widget_name, const gchar *string1, const gchar *string2,
                gint int1, gint int2);

GtkWidget*
dview_new (const gchar *widget_name, const gchar *string1, const gchar *string2,
                gint int1, gint int2);

void
on_raw_opcodes_activate                (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_enc_opcodes_activate                (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_comments_activate                   (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_new_errorlog_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_soft_reset_activate                 (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_hard_reset_activate                 (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_exit_activate                       (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_chunks_1_activate                   (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_chunks_2_activate                   (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_chunks_4_activate                   (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_reverse_activate                    (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_ibpl_activate                       (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_dbpl_activate                       (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

GtkWidget*
dview_new (const gchar *widget_name, const gchar *string1, const gchar *string2,
                gint int1, gint int2);

void
on_raw_opcodes_activate                (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_enc_opcodes_activate                (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_comments_activate                   (GtkMenuItem     *menuitem,
                                        gpointer         user_data);
